summaryrefslogtreecommitdiff
path: root/compilerplugins/clang/getimplementationname.cxx
diff options
context:
space:
mode:
Diffstat (limited to 'compilerplugins/clang/getimplementationname.cxx')
-rw-r--r--compilerplugins/clang/getimplementationname.cxx6
1 files changed, 3 insertions, 3 deletions
diff --git a/compilerplugins/clang/getimplementationname.cxx b/compilerplugins/clang/getimplementationname.cxx
index b918dc62da01..7e90b3818011 100644
--- a/compilerplugins/clang/getimplementationname.cxx
+++ b/compilerplugins/clang/getimplementationname.cxx
@@ -8,7 +8,7 @@
*/
// only compile this on unixy system
// as we dont want to bother with x-platform system()/mkdir()
#if defined(__unix__)
// only compile this on clang 3.7 or higher, which is known to work
// there were problems on clang 3.5 at least
@@ -292,7 +292,7 @@ std::string GetImplementationName::initOutdir() {
return result;
}
report(
- clang::DiagnosticsEngine::Error, "WORKDIR unset, dont know where to write service implementation info.");
+ clang::DiagnosticsEngine::Error, "WORKDIR unset, don't know where to write service implementation info.");
return std::string();
}
}
@@ -302,7 +302,7 @@ std::string GetImplementationName::initSrcdir() {
char* pSrcdir = getenv("SRCDIR");
if(!pSrcdir) {
report(
- clang::DiagnosticsEngine::Error, "SRCDIR unset, dont know where the source base is.");
+ clang::DiagnosticsEngine::Error, "SRCDIR unset, don't know where the source base is.");
}
return std::string(pSrcdir);
}
@@ -8,7 +8,7 @@
*/
// only compile this on unixy system
-// as we dont want to bother with x-platform system()/mkdir()
+// as we don't want to bother with x-platform system()/mkdir()
#if defined(__unix__)
// only compile this on clang 3.7 or higher, which is known to work